@@ -44,13 +44,15 @@ OPTIONAL_SECTIONS = ['workflow_tasks', 'cellv2_discovery']
 REQUIRED_DOCKER_SECTIONS = ['service_name', 'docker_config', 'puppet_config',
                             'config_settings']
 OPTIONAL_DOCKER_SECTIONS = ['docker_puppet_tasks', 'upgrade_tasks',
+                            'pre_upgrade_rolling_tasks',
                             'fast_forward_upgrade_tasks',
+                            'fast_forward_post_upgrade_tasks',
                             'post_upgrade_tasks',  'update_tasks',
-                            'service_config_settings', 'host_prep_tasks',
-                            'metadata_settings', 'kolla_config',
-                            'global_config_settings', 'logging_source',
-                            'logging_groups', 'external_deploy_tasks',
-                            'external_post_deploy_tasks',
+                            'post_update_tasks', 'service_config_settings',
+                            'host_prep_tasks', 'metadata_settings',
+                            'kolla_config', 'global_config_settings',
+                            'logging_source', 'logging_groups',
+                            'external_deploy_tasks', 'external_post_deploy_tasks',
                             'docker_config_scripts', 'step_config']
 REQUIRED_DOCKER_PUPPET_CONFIG_SECTIONS = ['config_volume', 'step_config',
                                           'config_image']
@@ -128,7 +130,8 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                    'NovaComputeExtraConfig': ['description'],
                                    'controllerExtraConfig': ['description'],
                                    'DockerSwiftConfigImage': ['default'],
-                                   'input_values': ['default']
+                                   'input_values': ['default'],
+                                   'fixed_ips': ['default', 'type']
                                    }
 
 PREFERRED_CAMEL_CASE = {
@@ -524,6 +527,11 @@ def validate_docker_service(filename, tpl):
                 print('ERROR: fast_forward_upgrade_tasks validation failed')
                 return 1
 
+        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
+            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
+                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
+                return 1
+
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -581,6 +589,11 @@ def validate_service(filename, tpl):
                 print('ERROR: fast_forward_upgrade_tasks validation failed')
                 return 1
 
+        if 'fast_forward_post_upgrade_tasks' in role_data and role_data['fast_forward_post_upgrade_tasks']:
+            if validate_upgrade_tasks(role_data['fast_forward_post_upgrade_tasks']):
+                print('ERROR: fast_forward_post_upgrade_tasks validation failed')
+                return 1
+
     if 'parameters' in tpl:
         for param in required_params:
             if param not in tpl['parameters']:
@@ -721,6 +734,10 @@ def validate(filename, param_map):
         if filename.startswith('./network_data_'):
             retval = validate_network_data_file(filename)
 
+        if retval == 0 and is_heat_template:
+            # check for old style nic config files
+            retval = validate_nic_config_file(filename, tpl)
+
     except Exception:
         print(traceback.format_exc())
         return 1
@@ -792,6 +809,22 @@ def validate_network_data_file(data_file_path):
         return 1
     return 0
 
+def validate_nic_config_file(filename, tpl):
+    try:
+        if isinstance(tpl.get('resources', {}), dict):
+            for r in (tpl.get('resources', {})).items():
+                if (r[1].get('type') == 'OS::Heat::StructuredConfig' and
+                    r[1].get('properties', {}).get('group') == 'os-apply-config' and
+                    r[1].get('properties', {}).get('config', {}).get('os_net_config')):
+                    print('ERROR: Using old format of nic configuration file: %s' % filename)
+                    print('tools/yaml-nic-config-2-script.py can be used to convert to new format')
+                    return 1
+
+    except Exception:
+        print(traceback.format_exc())
+        return 1
+    return 0
+
 def parse_args():
     p = argparse.ArgumentParser()
 
